@@ -19,12 +19,12 @@ rescale<-function(x,newrange) {
  }
 }
 
-# plots data as radial lines on a 24 hour "clockface" going clockwise.
-# radial.pos and radial.range should be in hours.
+# plots data as radial lines or a polygon on a 24 hour "clockface" going 
+# clockwise. radial.pos and radial.range should be in hours.
 # Remember to convert hour/minute values to hour/decimal values.
 # example: clock24.plot(rnorm(16)+3,seq(5.5,20.5))
 
-clock24.plot<-function(lengths,clock.pos,...) {
+clock24.plot<-function(lengths,clock.pos,rp.type="r",...) {
  npos<-length(lengths)
  # if no positions are given, spread the lines out over the circle 
  if(missing(clock.pos)) clock.pos<-seq(0,24-24/(npos+1),length=npos)
@@ -36,14 +36,16 @@ clock24.plot<-function(lengths,clock.pos,...) {
  clock.radial.pos<-rescale(c(clock.pos,radial.range),newrange)[1:npos]
  clock.labels<-as.character(seq(100,2400,by=100))
  clock.label.pos<-seq(29*pi/12,pi/2,by=-pi/12)
- radial.plot(lengths,clock.radial.pos,newrange,clock.labels,clock.label.pos,...)
+ radial.plot(lengths,clock.radial.pos,newrange,clock.labels,clock.label.pos,
+  rp.type=rp.type,...)
 }
 
-# plots data as radial lines starting at the right and going counterclockwise
+# plots data as radial lines or a polygon starting at the right and going
+# counterclockwise.
 # angles should be given in 0-360 values, use radial.plot for radians
 # example: polar.plot(rnorm(20)+3,seq(90,280,by=10))
 
-polar.plot<-function(lengths,polar.pos,labels,label.pos,...) {
+polar.plot<-function(lengths,polar.pos,labels,label.pos,rp.type="r",...) {
  npos<-length(lengths)
  # if no positions are given, add the average distance between positions so that
  # the first and last line don't overlap
@@ -60,17 +62,17 @@ polar.plot<-function(lengths,polar.pos,labels,label.pos,...) {
  radial.pos<-rescale(c(polar.pos,polar.range),newrange)[1:npos]
  nlabels<-length(labels)
  label.pos<-rescale(c(label.pos,0,360),c(0,2*pi))[1:nlabels]
- radial.plot(lengths,radial.pos,newrange,labels,label.pos,...)
+ radial.plot(lengths,radial.pos,newrange,labels,label.pos,rp.type=rp.type,...)
 }
 
-# plots radial lines of length 'lengths' from a central origin
-# at the angles specified by 'radial.pos' in radians
+# plots radial lines of length 'lengths' or a polygon with corresponding
+# vertices specified by 'radial.pos' in radians.
 # starts at the 'east' position and goes counterclockwise
 # label.prop is the proportion of max(lengths) that gives the
 # radial position of the labels
 
 radial.plot<-function(lengths,radial.pos,radial.range,labels,label.pos,
- label.prop=1.1,main="",xlab="",ylab="",...) {
+ rp.type="r",label.prop=1.1,main="",xlab="",ylab="",...) {
  maxlength<-label.prop*max(lengths)
  # calculate missing range as above
  if(missing(radial.range)) {
@@ -84,8 +86,19 @@ radial.plot<-function(lengths,radial.pos,radial.range,labels,label.pos,
  xpos<-cos(radial.pos)*lengths
  # get the vector of y positions
  ypos<-sin(radial.pos)*lengths
- segments(0,0,xpos,ypos,...)
- if(missing(labels)) labels<-as.character(round(radial.pos,2))
+ # plot radial lines if rp.type == "r"    
+ if(rp.type == "r") segments(0,0,xpos,ypos,...)
+ else polygon(xpos,ypos,...)
+ if(missing(labels)) {
+  if(length(radial.pos) <= 20) {
+   labels<-as.character(round(radial.pos,2))
+   label.pos<-radial.pos
+  }
+  else {
+   label.pos<-seq(0,1.95*pi,length=19)
+   labels<-as.character(round(label.pos,2))
+  }
+ }
  if(missing(label.pos)) {
   xpos<-cos(radial.pos)*maxlength
   ypos<-sin(radial.pos)*maxlength
@@ -94,6 +107,6 @@ radial.plot<-function(lengths,radial.pos,radial.range,labels,label.pos,
   xpos<-cos(label.pos)*maxlength
   ypos<-sin(label.pos)*maxlength
  }
- text(xpos,ypos,labels)
+ text(xpos,ypos,adj=0.5,labels)
 }
 
